# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][clog], and this project adheres to [Semantic Versioning][semver].

## [Unreleased]

## [0.6.0] - 2021-05-17
### Removed
- Drop support for python 3.6.0 and 3.6.1

### Changed
- Updated jinja2 version

## [0.5.0] - 2021-03-22
### Added
- Added an option to allow variables in toml files

## [0.4.0] - 2021-03-01
### Added
- Added an option to disallow undefined variables in templates

## [0.3.0] - 2019-12-24
### Added
- Env vars are now the default values of the template variables

## [0.2.0] - 2019-11-25
### Changed
- The output of the parser is printed to the stdout

## [0.1.0] - 2019-11-22
### Added
- Added a template parser


[unreleased]: https://github.com/spapanik/yashiro/compare/v0.6.0...main
[0.6.0]: https://github.com/spapanik/yashiro/compare/v0.5.0...v0.6.0
[0.5.0]: https://github.com/spapanik/yashiro/compare/v0.4.0...v0.5.0
[0.4.0]: https://github.com/spapanik/yashiro/compare/v0.3.0...v0.4.0
[0.3.0]: https://github.com/spapanik/yashiro/compare/v0.2.0...v0.3.0
[0.2.0]: https://github.com/spapanik/yashiro/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/spapanik/yashiro/releases/tag/v0.1.0

[clog]: https://keepachangelog.com/en/1.0.0/
[semver]: https://semver.org/spec/v2.0.0.html
